@@ -2,7 +2,7 @@
 package Tapper::MCP::Master;
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Wait for new testruns and start a new child when needed
-$Tapper::MCP::Master::VERSION = '5.0.3';
+$Tapper::MCP::Master::VERSION = '5.0.4';
 use 5.010;
         use Moose;
         use parent "Tapper::MCP";
@@ -51,6 +51,7 @@ sub cleanup_output_dir
                 my ($self) = @_;
                 $SIG{CHLD} = sub {
                         $self->dead_child($self->dead_child + 1);
+                        $self->log->debug("SIGCHLD - counter: ".$self->dead_child);
                 };
 
                 # give me a stack trace when ^C
@@ -82,11 +83,14 @@ sub cleanup_output_dir
                         $self->dead_child($self->dead_child - 1);
                         next if not $self->child->{$dead_pid}; # sig raised by qx()
 
-                        my $host = $self->child->{$dead_pid}->{job}->host->name;
-                        $self->log->debug("test on $host finished");
-                        $self->scheduler->mark_job_as_finished( $self->child->{$dead_pid}->{job} );
+                        my $job = $self->child->{$dead_pid}->{job};
+                        my $host = $job->host->name;
+                        my $testrun = $job->testrun->id;
+                        $self->log->debug("Testrun $testrun (pid $dead_pid) on host '$host' finished as dead process");
+                        $self->scheduler->mark_job_as_finished( $job );
                         delete $self->child->{$dead_pid};
                 }
+                $self->log->debug("handled dead processes - SIGCHLD - counter: ".$self->dead_child);
         }
 
 
@@ -161,9 +165,8 @@ sub cleanup_output_dir
                         if ($retval) {
                                 $self->log->error("Testrun $id ($system) error occurred: $retval");
                         } else {
-                                $self->log->info("Testrun $id ($system) finished successfully");
+                                $self->log->debug("Testrun $id (pid $$) on host '$system' finished successfully");
                         }
-                        $self->scheduler->mark_job_as_finished($job);
                         exit 0;
                 } else {
 
